diff --git a/js/reveal.js b/js/reveal.js
index d2a28c24f0281b3977798651eaafd9bd2225286d..f172c13e4133433cdc8bb0cc85f786211f956723 100644
--- a/js/reveal.js
+++ b/js/reveal.js
@@ -1266,8 +1266,8 @@
 			scale = Math.max( scale, config.minScale );
 			scale = Math.min( scale, config.maxScale );
 
-			// Prefer zooming in desktop WebKit so that content remains crisp
-			if( !isMobileDevice && /webkit/i.test( navigator.userAgent ) && typeof dom.slides.style.zoom !== 'undefined' ) {
+			// Prefer zooming in desktop Chrome so that content remains crisp
+			if( !isMobileDevice && /chrome/i.test( navigator.userAgent ) && typeof dom.slides.style.zoom !== 'undefined' ) {
 				dom.slides.style.zoom = scale;
 			}
 			// Apply scale transform as a fallback